.. depman documentation master file, created by
   sphinx-quickstart on Sat Jul 30 00:40:45 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Contents:
=========
.. toctree::
   :maxdepth: 2

   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

